@@ -3,7 +3,7 @@
 /*
     Rubber Band Library
     An audio time-stretching and pitch-shifting library.
-    Copyright 2007-2020 Particular Programs Ltd.
+    Copyright 2007-2021 Particular Programs Ltd.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -466,6 +466,10 @@ RubberBandStretcher::Impl::calculateSizes()
                 outputIncrement /= 2;
                 inputIncrement = int(outputIncrement / r);
             }
+            while (inputIncrement < 1) {
+                outputIncrement *= 2;
+                inputIncrement = int(outputIncrement / r);
+            }
             size_t minwin = roundUp(lrint(outputIncrement * windowIncrRatio));
             if (windowSize < minwin) windowSize = minwin;
 
@@ -501,6 +505,10 @@ RubberBandStretcher::Impl::calculateSizes()
                 outputIncrement /= 2;
                 inputIncrement = int(outputIncrement / r);
             }
+            while (inputIncrement < 1) {
+                outputIncrement *= 2;
+                inputIncrement = int(outputIncrement / r);
+            }
             windowSize = std::max(windowSize, roundUp(outputIncrement * 6));
             if (r > 5) while (windowSize < 8192) windowSize *= 2;
         }
@@ -664,9 +672,12 @@ RubberBandStretcher::Impl::configure()
 
             if (m_channelData[c]->resampler) continue;
 
-            m_channelData[c]->resampler =
-                new Resampler(Resampler::FastestTolerable, 1, 4096 * 16,
-                              m_debugLevel);
+            Resampler::Parameters params;
+            params.quality = Resampler::FastestTolerable;
+            params.maxBufferSize = 4096 * 16;
+            params.debugLevel = m_debugLevel;
+            
+            m_channelData[c]->resampler = new Resampler(params, 1);
 
             // rbs is the amount of buffer space we think we'll need
             // for resampling; but allocate a sensible amount in case
@@ -805,9 +816,12 @@ RubberBandStretcher::Impl::reconfigure()
 
             std::cerr << "WARNING: reconfigure(): resampler construction required in RT mode" << std::endl;
 
-            m_channelData[c]->resampler =
-                new Resampler(Resampler::FastestTolerable, 1, m_sWindowSize,
-                              m_debugLevel);
+            Resampler::Parameters params;
+            params.quality = Resampler::FastestTolerable;
+            params.maxBufferSize = m_sWindowSize;
+            params.debugLevel = m_debugLevel;
+            
+            m_channelData[c]->resampler = new Resampler(params, 1);
 
             size_t rbs = 
                 lrintf(ceil((m_increment * m_timeRatio * 2) / m_pitchScale));
